@@ -1,7 +1,7 @@
 /*
  *  This file is part of gpw.
  *
- *  Copyright (C) 2013-2014 Bruce Korb, all rights reserved.
+ *  Copyright (C) 2013-2015 Bruce Korb, all rights reserved.
  *  This is free software. It is licensed for use, modification and
  *  redistribution under the terms of the GNU General Public License,
  *  version 3 or later <http://gnu.org/licenses/gpl.html>
@@ -39,7 +39,6 @@ static void
 adjust_pw(char * buf, size_t bsz, unsigned char * data, size_t d_len);
 
 #if SIZEOF_CHARP > 4
-#else
 #endif
 static void
 get_dft_pw(char * buf, size_t bsz,
@@ -53,7 +52,7 @@ static void
 print_pwid_status(char const * name);
 
 static void
-select_chars(char * txtbuf);
+select_chars(unsigned char * txtbuf);
 
 static void
 print_pwid(char const * name);
@@ -87,6 +86,7 @@ sanity_check_cclass(void);
 /*
  * FILE: cfg-file.c
  */
+#ifndef SORT_PW_CFG // code for gnu-pw-mgr only
 static char const *
 access_config_file(void);
 
@@ -99,6 +99,7 @@ secure_cfg_file(void);
 static char const *
 load_config_file(void);
 
+#endif // not SORT_PW_CFG only
 static char const *
 find_home(void);
 
@@ -112,12 +113,6 @@ find_cfg_name(void);
 static void
 clean_triplets(char * pw);
 
-static uintptr_t
-ck_pw_classes(char * pw, bool no_spec, char ** first_ch, char ** second_ch);
-
-static void
-fix_old_pw(char * pw);
-
 static void
 fix_no_alpha_pw(char * pw);
 
@@ -174,6 +169,9 @@ remove_opt(char const * txt, char const * mark, size_t m_len,
 static void
 update_pwid_opts(char const * name);
 
+static void
+remove_pwid(char const * name);
+
 static char const *
 next_pwid_opt(char const * scan, char const * mark, size_t mark_len);
 
@@ -190,7 +188,7 @@ randomize_seed(int wiggle);
 static char const *
 get_seed_text(void);
 
-static void
+static uint32_t
 ver_str_to_number(void);
 
 static void
